@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -38,6 +38,7 @@ import com.openexchange.ajax.login.LoginTools;
 import com.openexchange.authentication.Authenticated;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.contexts.Context;
+import com.openexchange.java.Strings;
 import com.openexchange.login.LoginRequest;
 import com.openexchange.saml.SAMLConfig;
 import com.openexchange.saml.SAMLExceptionCode;
@@ -126,11 +127,25 @@ public abstract class AbstractSAMLBackend implements SAMLBackend {
 
     @Override
     public LoginRequest prepareLoginRequest(HttpServletRequest httpRequest, LoginConfiguration loginConfiguration, User user, Context context) throws OXException {
-        String login = user.getLoginInfo() + '@' + context.getLoginInfo()[0];
+        String login = user.getLoginInfo() + '@' + getSuitableContextLoginInfo(context);
         String defaultClient = loginConfiguration.getDefaultClient();
         return LoginTools.parseLogin(httpRequest, login, null, false, defaultClient, loginConfiguration.isCookieForceHTTPS(), false);
     }
 
+    private static String getSuitableContextLoginInfo(Context context) {
+        String ctxLoginInfo = null;
+        String[] ctxLoginInfos = context.getLoginInfo();
+        for (int j = 0; ctxLoginInfo == null && j < ctxLoginInfos.length; j++) {
+            String li = ctxLoginInfos[j];
+            if (Strings.parsePositiveInt(li) >= 0) {
+                // Context identifier. Skip...
+            } else {
+                ctxLoginInfo = li;
+            }
+        }
+        return (ctxLoginInfo == null ? Integer.toString(context.getContextId()) : ctxLoginInfo);
+    }
+
     /**
      * @see SAMLBackend#enhanceAuthenticated(Authenticated, Map)
      */
@@ -197,9 +212,9 @@ public abstract class AbstractSAMLBackend implements SAMLBackend {
             DefaultAuthnRequestInfo defaultAuthnRequestInfo = new DefaultAuthnRequestInfo();
             String string = new String(Base64.decode(relayState.getBytes(StandardCharsets.ISO_8859_1)));
             LOG_ABSTRACT.debug("decoded RelayState: {}", string);
-            String[] splitRelayState = string.split(":");
+            String[] splitRelayState = Strings.splitByColon(string);
             for (String s : splitRelayState) {
-                String[] split = s.split("=");
+                String[] split = Strings.splitBy(s, '=', true);
                 if (null != split && split.length == 2) {
                     switch (split[0]) {
                         case "domain":
